measureAsymmetry = function(eset, batchAnnot="Batch")
{
	# Some checks
	if(!is.element(batchAnnot,colnames(pData(eset))))
	{
		err("No batch information provided!")
	}
	nr_studies = length(unique(pData(eset)[,batchAnnot]))
	if(nr_studies==1)
	{
		err("Only one batch!")
	}
	#Columnwise normalize the data
	temp = t(exprs(eset))
	temp = apply(temp, 1, function(x){x-mean(x, na.rm=TRUE)});
  	temp = apply(temp, 1, function(x){x/sd(x, na.rm=TRUE)});
	exprs(eset) = t(temp)		

	# Run over all samples
	index = 0;
	for(study in unique(pData(eset)[,batchAnnot]))
	{
		idx = which(pData(eset)[,batchAnnot]==study);
		eset1 = eset[,idx];
		eset2 = eset[,-idx];
		
		#Compute samples' assymetry for each study
		assymS1 = mat.or.vec(1,dim(eset1)[2])
		assymS2 = mat.or.vec(1,dim(eset2)[2])
	
		for(i in 1:dim(eset1)[2])
		{
			assymS1[i] = mean(exprs(eset1)[,i]) - median(exprs(eset1)[,i]);
		} 
	
		for(i in 1:dim(eset2)[2])
		{
			assymS2[i] = mean(exprs(eset2)[,i]) - median(exprs(eset2)[,i]);
		} 

		#Estimates the pdfs of genes assymetry per study
		pdf1 = density(assymS1,from = (min(min(assymS1),min(assymS2))-5), to = (max(max(assymS1),max(assymS2))+5) ); 
		pdf1$y = pdf1$y/sum(pdf1$y);
		cdf1 = cumsum(pdf1$y/sum(pdf1$y)); 
		pdf2 = density(assymS2,from = (min(min(assymS1),min(assymS2))-5), to = (max(max(assymS1),max(assymS2))+5) ); 
		pdf2$y = pdf2$y/sum(pdf2$y);
		cdf2 = cumsum(pdf2$y/sum(pdf2$y));		

		cur_index = (sum(abs(cdf1-cdf2)))/length(cdf1);
		index = index + cur_index
	}
	
	return(index/length(unique(pData(eset)[,batchAnnot])));

}
