measureSignificantGenesOverlap = function(esetBEFORE, esetAFTER, batchAnnot="Batch", targetAnnot)
{
  # TODO put it in util.R ?
  removeUnknownSamples = function(eset, label)
  {
    values = c("NILL","NA",NA,"UNKNOWN");
    idx = which(is.element(pData(eset)[,label], values));
    if(length(idx) > 0) { eset = eset[,-idx]; }
    return(eset);
  }

	# Some checks
	if(!is.element(batchAnnot,colnames(pData(esetAFTER))))
	{
		err("Incorrect batch annotation provided!")
	}
  if(!is.element(targetAnnot,colnames(pData(esetAFTER))))
  {
    err("Incorrect target annotation provided!")
  }
	nr_studies = length(unique(pData(esetAFTER)[,batchAnnot]))
	if(nr_studies==1)
	{
		err("Only one batch!")
	}
  	
  # Clean up merged data set
  eset = removeUnknownSamples(esetAFTER, targetAnnot);
	#Columnwise normalize the data
	temp = t(exprs(eset))
	temp = apply(temp, 1, function(x){x-mean(x, na.rm=TRUE)});
  	temp = apply(temp, 1, function(x){x/sd(x, na.rm=TRUE)});
	exprs(eset) = t(temp)
	#Compute lists of significant genes for the merged eset
	x = exprs(eset); y = pData(eset)[,targetAnnot];
	
	design <- cbind(Grp1=1,Grp2vs1=y)
	fitted = lmFit(x,design);

	results <- eBayes(fitted);
	results = topTable(results, coef=2, number=dim(x)[1], adjust.method="BH",confint=FALSE);
	resultsSorted = results[order(abs(results[,6]),decreasing=TRUE),];		
	List = resultsSorted[which(resultsSorted[,5]<0.05),];
	
	
  	# Find DEG for individual data sets prior to transformation
  	esetBEFORE = removeUnknownSamples(esetBEFORE, targetAnnot);
  	
  	unionList = NULL;
	for(study in unique(pData(esetBEFORE)[,batchAnnot]))
	{
		idx = which(pData(eset)[,batchAnnot]==study);
		eset1 = esetBEFORE[,idx];
		
		#Compute lists of significant genes for individual eset
		x1 = exprs(eset1); y1 = pData(eset1)[,targetAnnot];

        design1 <- cbind(Grp1=1,Grp2vs1=y1)
        fitted1 = lmFit(x1,design1);

        results1 <- eBayes(fitted1);
        results1 = topTable(results1, coef=2, number=dim(x)[1], adjust.method="BH",confint=FALSE);
        resultsSorted1 = results1[order(abs(results1[,6]),decreasing=TRUE),];
        List1 = resultsSorted1[which(resultsSorted1[,5]<0.05),];   

        unionList = rbind(unionList, List1);
	}
	index = length(intersect(unique(unionList[,1]), List[,1]))/length(unique(unionList[,1]));
	
	return(index)
}
