# plot gene-wise desnity functions
#-------------------------------------------------------------------------------
plotGeneWiseDensity = function(eset, batchAnnot="Batch", gene=NULL, legend=TRUE, 
                               file=NULL, main=NULL, ...)
{
  if(! is.null(file)) { pdf(file, width=12, height=7); }

  if(is.null(gene)) 
  { 
    s = sample(1:nrow(exprs(eset)), 1); 
    gene = rownames(exprs(eset))[s];
  }

  if(is.null(main)) { main=gene; }
  
  colMap = makeColorMap(eset, batchAnnot); 

  #--Add margin to the right for the legend 
  tmp = par()$mar;
  if(legend) { par(xpd=T, mar=par()$mar+c(0,0,0,8)); }
  
  #--Get densities for each batch 
  densities = list();
  colVec = NULL;

  batches = sort(unique(pData(eset)[,batchAnnot]));
  for(i in 1:length(batches))
  {  
    batch = batches[[i]]
    idx = pData(eset)[,batchAnnot]==batch;
    density = density(exprs(eset)[gene,idx],from = 0, to = 15);
    densities[[i]] = density;
    colVec = c(colVec, colMap[[batch]]);
  }

  #--Calculate plot boundaries 
  xlim = c(0,15);
  ylim = c(0,max(unlist(lapply(densities,function(x){max(x$y)}))));

  #--Plot densities
  for(i in 1:length(densities))
  {
    # Only for the first line add layout.
    if(i==1)
    {
      plot(densities[[i]],xlim=xlim, ylim=ylim, col=colVec[i],
           xlab="", ylab="", main=main,
           panel.first={U = par("usr"); 
                        rect(U[1],U[3],U[2],U[4],col="azure2",
                             border="black", lwd=3);},
           ...);
    }
    # For the other lines just add them.
    else 
    {
      par(new=TRUE);
      plot(densities[[i]],xlim=xlim, ylim=ylim, col=colVec[i],
           xlab="", ylab="", main="");
    } 
  }

  #--Add legend
  if(legend)
  {
    x = xlim[2] + (xlim[2] - xlim[1]) * 0.1;
    y = ylim[2] - (ylim[2] - ylim[1]) * 0.1; 

    legend(x,y,
           legend = names(colMap),
           pt.lwd=2,
           pch = 19,
           col = unlist(colMap),
           box.lwd=3,
           bg="azure2");

    #--Reset margin
    par(xpd=F, mar=tmp);
  }
  
  if(! is.null(file)) { dev.off(); }
}
