\name{measureAsymmetry}
\alias{measureAsymmetry}
\title{Calculate asymmetry index for (merged) ExpressionSet}
\description{measureAsymmetry compares the distribution of samples asymmetry, quantified by the skewness, before and after batch effect removal. This index should have a value close to 0}

\usage{
measureAsymmetry(eset, batchAnnot="Batch")
}

\arguments{
\item{eset}{ExpressionSet object.}
\item{batchAnnot}{Column in pData(eset) containing the batch information.}
}

\examples{

# retrieve two datasets:
library(inSilicoDb);
eset1 = getDataset("GSE19804", "GPL570", norm="FRMA", genes=TRUE);
eset2 = getDataset("GSE10072", "GPL96",  norm="FRMA", genes=TRUE);
esets = list(eset1,eset2);

# merge them using the 'NONE' and 'COMBAT' method:
library(inSilicoMerging);
eset_NONE = merge(esets, method="NONE");
eset_COMBAT = merge(esets, method="COMBAT");

# check available annotations:
colnames(pData(eset_NONE));
table(pData(eset_NONE)[,"Study"]);

# Calculate asymmetry index for both datasets
measureAsymmetry(eset_NONE, batchAnnot="Study");
measureAsymmetry(eset_COMBAT, batchAnnot="Study");

}
