\name{measureGenesMeanCorrCoef}
\alias{measureGenesMeanCorrCoef}
\title{Calculate gene mean correlation coefficient between two independent studies before and after applying batch effect removal methods.}
\description{Calculate gene mean correlation coefficient between two independent studies before and after applying batch effect removal methods. Methods that least affects the data should be preferred.}

\usage{
measureGenesMeanCorrCoef(esetBEFORE, esetAFTER, batchAnnot="Batch")
}

\arguments{
\item{esetBEFORE}{ExpressionSet of combined study before applying batch removal method.}
\item{esetAFTER}{ExpressionSet of combined study after applying batch removal method.}
\item{batchAnnot}{Column in pData(eset) containing the batch information.}
}

\examples{

# retrieve two datasets:
library(inSilicoDb);
eset1 = getDataset("GSE19804", "GPL570", norm="FRMA", genes=TRUE);
eset2 = getDataset("GSE10072", "GPL96",  norm="FRMA", genes=TRUE);
esets = list(eset1,eset2);

# merge them using the 'NONE' and 'COMBAT' method:
library(inSilicoMerging);
eset_NONE = merge(esets, method="NONE");
eset_COMBAT = merge(esets, method="COMBAT");

# check available annotations:
colnames(pData(eset_NONE));
table(pData(eset_NONE)[,"Study"]);

# Calculate gene mean correlation coefficient for both datasets
measureGenesMeanCorrCoef(eset_NONE, eset_COMBAT, batchAnnot="Study");

}
