\name{measureSamplesOverlap}
\alias{measureSamplesOverlap}
\title{Calculate Samples Overlap index for (merged) ExpressionSet}
\description{Measures the expected overlap of samples, the higher this overlap, the better the integration process.}

\usage{
measureSamplesOverlap(eset, batchAnnot="Batch")
}

\arguments{
\item{eset}{ExpressionSet object.}
\item{batchAnnot}{Column in pData(eset) containing the batch information.}
}

\examples{

# retrieve two datasets:
library(inSilicoDb);
eset1 = getDataset("GSE19804", "GPL570", norm="FRMA", genes=TRUE);
eset2 = getDataset("GSE10072", "GPL96",  norm="FRMA", genes=TRUE);
esets = list(eset1,eset2);

# merge them using the 'NONE' and 'COMBAT' method:
library(inSilicoMerging);
eset_NONE = merge(esets, method="NONE");
eset_COMBAT = merge(esets, method="COMBAT");

# check available annotations:
colnames(pData(eset_NONE));
table(pData(eset_NONE)[,"Study"]);

# Calculate Samples Overlap index for both datasets
measureSamplesOverlap(eset_NONE, batchAnnot="Study");
measureSamplesOverlap(eset_COMBAT, batchAnnot="Study");

}
