\name{measureSignificantGenesOverlap}
\alias{measureSignificantGenesOverlap}
\title{Compares the overlap in significant genes between two independent studies before and after applying batch effect removal methods.}
\description{The quality of batch effect removal is proportional to the number of significant differentially expressed genes (DEGs) found in the newly combined study which are also found in all of the individual studies to be combined.}

\usage{
measureSignificantGenesOverlap(esetBEFORE, esetAFTER, batchAnnot="Batch", targetAnnot)
}

\arguments{
\item{esetBEFORE}{ExpressionSet of combined study before applying batch removal method.}
\item{esetAFTER}{ExpressionSet of combined study after applying batch removal method.}
\item{batchAnnot}{Column in pData(eset) containing the individual batch information.}
\item{targetAnnot}{Column in pData(eset) containing the biological variable of interest for finding differentially expressed genes.}
}

\examples{

# retrieve two datasets:
library(inSilicoDb);
eset1 = getDataset("GSE19804", "GPL570", norm="FRMA", genes=TRUE);
eset2 = getDataset("GSE10072", "GPL96",  norm="FRMA", genes=TRUE);
esets = list(eset1,eset2);

# merge them using the 'NONE' and 'COMBAT' method:
library(inSilicoMerging);
eset_NONE = merge(esets, method="NONE");
eset_COMBAT = merge(esets, method="COMBAT");

# check available annotations:
colnames(pData(eset_NONE));
table(pData(eset_NONE)[,"Study"]);
table(pData(eset_NONE)[,"Disease"]);

# Calculate significant genes overlap index for both datasets
measureSignificantGenesOverlap(eset_NONE, eset_COMBAT, batchAnnot="Study", targetAnnot="Disease");

}
