\name{plotDendrogram}
\alias{plotDendrogram}
\title{Create dendrogram from (merged) ExpressionSet}
\description{Create dendrogram from ExpressionSet after performing hierachical clustering.}

\usage{
plotDendrogram(eset, batchAnnot="Batch", legend=TRUE, file=NULL, ...)
}

\arguments{
\item{eset}{ExpressionSet object.}
\item{batchAnnot}{Column in pData(eset) containing the batch information.}
\item{legend}{If TRUE a legend will be provided next to the dendrogram plot.}
\item{file}{If defined, the resulting plot will be stored as a pdf file instead of shown interactively.}
\item{...}{Additional parameters for the 'plot' function (e.g. 'main').}
}

\examples{

# retrieve two datasets:
library(inSilicoDb);
eset1 = getDataset("GSE19804", "GPL570", norm="FRMA", genes=TRUE);
eset2 = getDataset("GSE10072", "GPL96",  norm="FRMA", genes=TRUE);
esets = list(eset1,eset2);

# merge them using the 'NONE' and 'COMBAT' method:
library(inSilicoMerging);
eset_NONE = merge(esets, method="NONE");
eset_COMBAT = merge(esets, method="COMBAT");

# check available annotations:
colnames(pData(eset_NONE));
table(pData(eset_NONE)[,"Study"]);

# Visual inspection of the two merged datasets through an MDS plot
plotDendrogram(eset_NONE, batchAnnot="Study");
plotDendrogram(eset_COMBAT, batchAnnot="Study");

}
