\name{plotGeneWiseDensity}
\alias{plotGeneWiseDensity}
\title{Create gene-wise density plots from (merged) ExpressionSet}
\description{Gene-wise density plots describe the distribution of genes across different samples.}

\usage{
plotGeneWiseDensity(eset, batchAnnot="Batch", gene=NULL, legend=TRUE, file=NULL, main=NULL, ...)
}

\arguments{
\item{eset}{ExpressionSet object.}
\item{batchAnnot}{Column in pData(eset) containing the individual batch information.}
\item{gene}{Gene for which the density plots will be created. If not specified a random gene will be selected.}
\item{legend}{If TRUE a legend will be provided next to the gene-wise density plot.}
\item{file}{If defined, the resulting plot will be stored as a pdf file instead of shown interactively.}
\item{main}{If defined, a title for the plot can be defined. If not defined the gene name will be selected.}
\item{...}{Additional parameters for the 'plot' function (e.g. 'main').}
}

\examples{

# retrieve two datasets:
library(inSilicoDb);
eset1 = getDataset("GSE19804", "GPL570", norm="FRMA", genes=TRUE);
eset2 = getDataset("GSE10072", "GPL96",  norm="FRMA", genes=TRUE);
esets = list(eset1,eset2);

# merge them using the 'NONE' and 'COMBAT' method:
library(inSilicoMerging);
eset_NONE = merge(esets, method="NONE");
eset_COMBAT = merge(esets, method="COMBAT");

# check available annotations:
colnames(pData(eset_NONE));
table(pData(eset_NONE)[,"Study"]);

# Visual inspection of a random gene in the two merged datasets
gene = sample(rownames(exprs(eset_NONE)), 1);
plotGeneWiseDensity(eset_NONE, batchAnnot="Study", gene=gene);
plotGeneWiseDensity(eset_COMBAT, batchAnnot="Study", gene=gene);

}
